@@ -1,20 +1,16 @@
 package commands
 
 import (
-	"github.com/git-lfs/git-lfs/lfs"
-	"github.com/git-lfs/git-lfs/localstorage"
 	"github.com/spf13/cobra"
 )
 
 // uninstallCmd removes any configuration and hooks set by Git LFS.
 func uninstallCommand(cmd *cobra.Command, args []string) {
-	opt := cmdInstallOptions()
-	if err := lfs.UninstallFilters(opt); err != nil {
+	if err := cmdInstallOptions().Uninstall(); err != nil {
 		Error(err.Error())
 	}
 
-	if localInstall || lfs.InRepo() {
-		localstorage.InitStorageOrFail()
+	if localInstall || cfg.InRepo() {
 		uninstallHooksCommand(cmd, args)
 	}
 
@@ -23,7 +19,7 @@ func uninstallCommand(cmd *cobra.Command, args []string) {
 
 // uninstallHooksCmd removes any hooks created by Git LFS.
 func uninstallHooksCommand(cmd *cobra.Command, args []string) {
-	if err := lfs.UninstallHooks(); err != nil {
+	if err := uninstallHooks(); err != nil {
 		Error(err.Error())
 	}
 
@@ -35,6 +31,5 @@ func init() {
 		cmd.Flags().BoolVarP(&localInstall, "local", "l", false, "Set the Git LFS config for the local Git repository only.")
 		cmd.Flags().BoolVarP(&systemInstall, "system", "", false, "Set the Git LFS config in system-wide scope.")
 		cmd.AddCommand(NewCommand("hooks", uninstallHooksCommand))
-		cmd.PreRun = setupLocalStorage
 	})
 }
