@@ -33,6 +33,16 @@ begin_test "migrate import (default branch)"
 )
 end_test
 
+begin_test "migrate import (bare repository)"
+(
+  set -e
+
+  setup_multiple_remote_branches
+
+  git lfs migrate import --everything
+)
+end_test
+
 begin_test "migrate import (given branch)"
 (
   set -e
@@ -202,6 +212,81 @@ begin_test "migrate import (given branch, exclude remote refs)"
 )
 end_test
 
+begin_test "migrate import (given ref, --skip-fetch)"
+(
+  set -e
+
+  setup_single_remote_branch
+
+  md_master_oid="$(calc_oid "$(git cat-file -p "refs/heads/master:a.md")")"
+  md_remote_oid="$(calc_oid "$(git cat-file -p "refs/remotes/origin/master:a.md")")"
+  txt_master_oid="$(calc_oid "$(git cat-file -p "refs/heads/master:a.txt")")"
+  txt_remote_oid="$(calc_oid "$(git cat-file -p "refs/remotes/origin/master:a.txt")")"
+
+  git tag pseudo-remote "$(git rev-parse refs/remotes/origin/master)"
+  # Remove the refs/remotes/origin/master ref, and instruct 'git lfs migrate' to
+  # not fetch it.
+  git update-ref -d refs/remotes/origin/master
+
+  git lfs migrate import --skip-fetch
+
+  assert_pointer "refs/heads/master" "a.md" "$md_master_oid" "50"
+  assert_pointer "pseudo-remote" "a.md" "$md_remote_oid" "140"
+  assert_pointer "refs/heads/master" "a.txt" "$txt_master_oid" "30"
+  assert_pointer "pseudo-remote" "a.txt" "$txt_remote_oid" "120"
+
+  assert_local_object "$md_master_oid" "50"
+  assert_local_object "$txt_master_oid" "30"
+  assert_local_object "$md_remote_oid" "140"
+  assert_local_object "$txt_remote_oid" "120"
+
+  master="$(git rev-parse refs/heads/master)"
+  remote="$(git rev-parse pseudo-remote)"
+
+  master_attrs="$(git cat-file -p "$master:.gitattributes")"
+  remote_attrs="$(git cat-file -p "$remote:.gitattributes")"
+
+  echo "$master_attrs" | grep -q "*.md filter=lfs diff=lfs merge=lfs"
+  echo "$master_attrs" | grep -q "*.txt filter=lfs diff=lfs merge=lfs"
+  echo "$remote_attrs" | grep -q "*.md filter=lfs diff=lfs merge=lfs"
+  echo "$remote_attrs" | grep -q "*.txt filter=lfs diff=lfs merge=lfs"
+)
+end_test
+
+begin_test "migrate import (un-annotated tags)"
+(
+  set -e
+
+  setup_single_local_branch_with_tags
+
+  txt_master_oid="$(calc_oid "$(git cat-file -p "refs/heads/master:a.txt")")"
+
+  git lfs migrate import --everything
+
+  assert_pointer "refs/heads/master" "a.txt" "$txt_master_oid" "2"
+  assert_local_object "$txt_master_oid" "2"
+
+  git tag --points-at "$(git rev-parse HEAD)" | grep -q "v1.0.0"
+)
+end_test
+
+begin_test "migrate import (annotated tags)"
+(
+  set -e
+
+  setup_single_local_branch_with_annotated_tags
+
+  txt_master_oid="$(calc_oid "$(git cat-file -p "refs/heads/master:a.txt")")"
+
+  git lfs migrate import --everything
+
+  assert_pointer "refs/heads/master" "a.txt" "$txt_master_oid" "2"
+  assert_local_object "$txt_master_oid" "2"
+
+  git tag --points-at "$(git rev-parse HEAD)" | grep -q "v1.0.0"
+)
+end_test
+
 begin_test "migrate import (include/exclude ref)"
 (
   set -e
@@ -242,6 +327,44 @@ begin_test "migrate import (include/exclude ref)"
 )
 end_test
 
+begin_test "migrate import (include/exclude ref args)"
+(
+  set -e
+
+  setup_multiple_remote_branches
+
+  md_master_oid="$(calc_oid "$(git cat-file -p "refs/heads/master:a.md")")"
+  md_remote_oid="$(calc_oid "$(git cat-file -p "refs/remotes/origin/master:a.md")")"
+  md_feature_oid="$(calc_oid "$(git cat-file -p "refs/heads/my-feature:a.md")")"
+  txt_master_oid="$(calc_oid "$(git cat-file -p "refs/heads/master:a.txt")")"
+  txt_remote_oid="$(calc_oid "$(git cat-file -p "refs/remotes/origin/master:a.txt")")"
+  txt_feature_oid="$(calc_oid "$(git cat-file -p "refs/heads/my-feature:a.txt")")"
+
+  git lfs migrate import my-feature ^master
+
+  assert_pointer "refs/heads/my-feature" "a.md" "$md_feature_oid" "31"
+  assert_pointer "refs/heads/my-feature" "a.txt" "$txt_feature_oid" "30"
+
+  assert_local_object "$md_feature_oid" "31"
+  refute_local_object "$md_master_oid" "21"
+  assert_local_object "$txt_feature_oid" "30"
+  refute_local_object "$txt_master_oid" "20"
+  refute_local_object "$md_remote_oid" "11"
+  refute_local_object "$txt_remote_oid" "10"
+
+  master="$(git rev-parse refs/heads/master)"
+  feature="$(git rev-parse refs/heads/my-feature)"
+  remote="$(git rev-parse refs/remotes/origin/master)"
+
+  [ ! $(git cat-file -p "$master:.gitattributes") ]
+  [ ! $(git cat-file -p "$remote:.gitattributes") ]
+  feature_attrs="$(git cat-file -p "$feature:.gitattributes")"
+
+  echo "$feature_attrs" | grep -q "*.md filter=lfs diff=lfs merge=lfs"
+  echo "$feature_attrs" | grep -q "*.txt filter=lfs diff=lfs merge=lfs"
+)
+end_test
+
 begin_test "migrate import (include/exclude ref with filter)"
 (
   set -e
@@ -343,7 +466,7 @@ begin_test "migrate import (prefix include(s))"
 (
   set -e
 
-  includes="foo${PATH_SEPARATOR}bar${PATH_SEPARATOR}baz ${PATH_SEPARATOR}foo foo${PATH_SEPARATOR}**${PATH_SEPARATOR}baz${PATH_SEPARATOR}a.txt *.txt"
+  includes="foo/bar/baz foo/**/baz/a.txt *.txt"
   for include in $includes; do
     setup_single_local_branch_deep_trees
 
@@ -380,6 +503,20 @@ begin_test "migrate import (--everything)"
 )
 end_test
 
+begin_test "migrate import (ambiguous reference)"
+(
+  set -e
+
+  setup_multiple_local_branches
+
+  # Create an ambiguously named reference sharing the name as the SHA-1 of
+  # "HEAD".
+  sha="$(git rev-parse HEAD)"
+  git tag "$sha"
+
+  git lfs migrate import --everything
+)
+end_test
 
 begin_test "migrate import (--everything with args)"
 (
@@ -403,8 +540,6 @@ begin_test "migrate import (--everything with --include-ref)"
 )
 end_test
 
-exit 0
-
 begin_test "migrate import (--everything with --exclude-ref)"
 (
   set -e
@@ -415,3 +550,69 @@ begin_test "migrate import (--everything with --exclude-ref)"
     "fatal: cannot use --everything with --include-ref or --exclude-ref" ]
 )
 end_test
+
+begin_test "migrate import (--everything and --include with glob pattern)"
+(
+  set -e
+
+  setup_multiple_local_branches
+
+  md_master_oid="$(calc_oid "$(git cat-file -p "refs/heads/master:a.md")")"
+  txt_master_oid="$(calc_oid "$(git cat-file -p "refs/heads/master:a.txt")")"
+  md_feature_oid="$(calc_oid "$(git cat-file -p "refs/heads/my-feature:a.md")")"
+  txt_feature_oid="$(calc_oid "$(git cat-file -p "refs/heads/my-feature:a.txt")")"
+
+  git lfs migrate import --verbose --everything --include='*.[mM][dD]'
+
+  assert_pointer "refs/heads/master" "a.md" "$md_master_oid" "140"
+  assert_pointer "refs/heads/my-feature" "a.md" "$md_feature_oid" "30"
+
+  assert_local_object "$md_master_oid" "140"
+  assert_local_object "$md_feature_oid" "30"
+  refute_local_object "$txt_master_oid"
+  refute_local_object "$txt_feature_oid"
+)
+end_test
+
+begin_test "migrate import (nested sub-trees and --include with wildcard)"
+(
+  set -e
+
+  setup_single_local_branch_deep_trees
+
+  oid="$(calc_oid "$(git cat-file -p :foo/bar/baz/a.txt)")"
+  size="$(git cat-file -p :foo/bar/baz/a.txt | wc -c | awk '{ print $1 }')"
+
+  git lfs migrate import --include="**/*ar/**"
+
+  assert_pointer "refs/heads/master" "foo/bar/baz/a.txt" "$oid" "$size"
+  assert_local_object "$oid" "$size"
+)
+end_test
+
+begin_test "migrate import (handle copies of files)"
+(
+  set -e
+
+  setup_single_local_branch_deep_trees
+
+  # add the object from the sub-tree to the root directory
+  cp foo/bar/baz/a.txt a.txt
+  git add a.txt
+  git commit -m "duplicated file"
+
+  oid_root="$(calc_oid "$(git cat-file -p :a.txt)")"
+  oid_tree="$(calc_oid "$(git cat-file -p :foo/bar/baz/a.txt)")"
+  size="$(git cat-file -p :foo/bar/baz/a.txt | wc -c | awk '{ print $1 }')"
+
+  # only import objects under "foo"
+  git lfs migrate import --include="foo/**"
+
+  assert_pointer "refs/heads/master" "foo/bar/baz/a.txt" "$oid_tree" "$size"
+  assert_local_object "$oid_tree" "$size"
+
+  # "a.txt" is not under "foo" and therefore should not be in LFS
+  oid_root_after_migration="$(calc_oid "$(git cat-file -p :a.txt)")"
+  [ "$oid_root" = "$oid_root_after_migration" ]
+)
+end_test
